<?php
namespace App\Middlewares;

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

class JwtManager {
    
    private $util;

    public function __construct(\App\Util\Util $util) {
        $this->util = $util;
    }

    public function jwtOperatorLogin($dataOperator) {
        $expirationTime = time() + (60 * 60 * 24); // Expira em um dia (60 segundos * 60 minutos * 24 horas)

        $id   = $dataOperator['ID'];
        $name = $dataOperator['NAME'];

        $operator = [
            'id' => $id,
            'nome' => $name
        ];

        $tokenPayload = [
            'exp' => $expirationTime,
            'operator' => $operator,
            'kid' => '1'
        ];
        $token = JWT::encode($tokenPayload, $this->util->getEnv("JWT_SECRET_KEY"), 'HS256');

        return $token;
    }

    public function verifyJwtToken($token) {
        try {
            $decoded = JWT::decode($token, new Key ($this->util->getEnv("JWT_SECRET_KEY"), 'HS256'));
          
            $currentTime = time();
            if ($decoded->exp < $currentTime) {
                return false;
            }
            return true;
        } catch (\Exception $e) {
            return false;
        }
    }

    public function jwtResetPassword($dataOperator) {
        $expirationTime = time() + (60 * 30);

        $id   = $dataOperator['ID'];
        $name = $dataOperator['NAME'];
        $email = $dataOperator['EMAIL'];

        $operator = [
            'id' => $id,
            'nome' => $name,
            'email' => $email
        ];

        $tokenPayload = [
            'exp' => $expirationTime,
            'operator' => $operator,
            'kid' => '1'
        ];
        $token = JWT::encode($tokenPayload, $this->util->getEnv("JWT_SECRET_KEY"), 'HS256');

        return $token;
    }

    public function getJwtTokenData($token) {
        try {
            $decoded = JWT::decode($token, new Key ($this->util->getEnv("JWT_SECRET_KEY"), 'HS256'));
          
            $currentTime = time();
            if ($decoded->exp < $currentTime) {
                return false;
            };
            return $decoded;
        } catch (\Exception $e) {
            return false;
        }
    }
}

